(Chai Profile) เป็นตัวอย่างการอัพโหลด package ไปยัง pypi.org
============================================================

PyPi: https://pypi.org/project/chaiprofile/

package ที่อธิบาย profile สามารถนำไปใช้กับผู้อื่นได้

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install chaiprofile

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

\```python my = Profile(‘Chai’) my.company = ‘aeroth’ my.hobby =
[‘Studying’,‘Reading’,‘Sleeping’] print(my.name) my.show_email()
my.show_myart() my.show_hobby()

พัฒนาโดย: ชัย ก. FB: https://www.facebook.com/ChaiMeehMeeh
